@@ -1,10 +1,17 @@
 #ifndef STAN_LANG_AST_HPP
 #define STAN_LANG_AST_HPP
 
-#include <stan/lang/ast/base_expr_type.hpp>
-#include <stan/lang/ast/expr_type.hpp>
 #include <stan/lang/ast/nil.hpp>
 #include <stan/lang/ast/origin_block.hpp>
+#include <stan/lang/ast/double_type.hpp>
+#include <stan/lang/ast/ill_formed_type.hpp>
+#include <stan/lang/ast/int_type.hpp>
+#include <stan/lang/ast/matrix_type.hpp>
+#include <stan/lang/ast/row_vector_type.hpp>
+#include <stan/lang/ast/vector_type.hpp>
+#include <stan/lang/ast/void_type.hpp>
+#include <stan/lang/ast/base_expr_type.hpp>
+#include <stan/lang/ast/expr_type.hpp>
 #include <stan/lang/ast/scope.hpp>
 #include <stan/lang/ast/variable_map.hpp>
 
@@ -63,13 +70,11 @@
 #include <stan/lang/ast/node/arg_decl.hpp>
 #include <stan/lang/ast/node/array_expr.hpp>
 #include <stan/lang/ast/node/assgn.hpp>
-#include <stan/lang/ast/node/assignment.hpp>
 #include <stan/lang/ast/node/base_var_decl.hpp>
 #include <stan/lang/ast/node/binary_op.hpp>
 #include <stan/lang/ast/node/break_continue_statement.hpp>
 #include <stan/lang/ast/node/cholesky_corr_var_decl.hpp>
 #include <stan/lang/ast/node/cholesky_factor_var_decl.hpp>
-#include <stan/lang/ast/node/compound_assignment.hpp>
 #include <stan/lang/ast/node/conditional_op.hpp>
 #include <stan/lang/ast/node/conditional_statement.hpp>
 #include <stan/lang/ast/node/corr_matrix_var_decl.hpp>
@@ -80,6 +85,8 @@
 #include <stan/lang/ast/node/expression.hpp>
 #include <stan/lang/ast/node/expression_type_vis.hpp>
 #include <stan/lang/ast/node/for_statement.hpp>
+#include <stan/lang/ast/node/for_array_statement.hpp>
+#include <stan/lang/ast/node/for_matrix_statement.hpp>
 #include <stan/lang/ast/node/fun.hpp>
 #include <stan/lang/ast/node/function_decl_def.hpp>
 #include <stan/lang/ast/node/function_decl_defs.hpp>
@@ -93,6 +100,7 @@
 #include <stan/lang/ast/node/int_var_decl.hpp>
 #include <stan/lang/ast/node/lb_idx.hpp>
 #include <stan/lang/ast/node/lub_idx.hpp>
+#include <stan/lang/ast/node/map_rect.hpp>
 #include <stan/lang/ast/node/matrix_var_decl.hpp>
 #include <stan/lang/ast/node/multi_idx.hpp>
 #include <stan/lang/ast/node/no_op_statement.hpp>
