@@ -40,8 +40,9 @@ namespace stan {
       if (sigs_map_.find(name) == sigs_map_.end())
         return false;
       const std::vector<function_signature_t> sigs = sigs_map_[name];
+      // check return type
       for (size_t i = 0; i < sigs.size(); ++i)
-        if (sig.second == sigs[i].second)
+        if (sig.first == sigs[i].first && sig.second == sigs[i].second)
           return true;
       return false;
     }
@@ -51,7 +52,7 @@ namespace stan {
                                         const function_signature_t& sig) {
       const std::vector<function_signature_t> sigs = sigs_map_[name];
       for (size_t i = 0; i < sigs.size(); ++i)
-        if (sig.second == sigs[i].second)
+        if (sig.first == sigs[i].first && sig.second == sigs[i].second)
           return sigs[i];
       expr_type ill_formed = expr_type();
       std::vector<function_arg_type> arg_types;
@@ -70,7 +71,7 @@ namespace stan {
       const vector<function_signature_t> sigs = it->second;
       for (size_t i = 0; i < sigs.size(); ++i) {
         if (sigs[i].second.size() == 0
-            || sigs[i].second[0].expr_type_.base_type_ != INT_T)
+            || !sigs[i].second[0].expr_type_.base_type_.is_int_type())
           return false;
       }
       return true;
@@ -188,34 +189,62 @@ namespace stan {
     }
 
     void function_signatures::add_nullary(const::std::string& name) {
-      add(name, DOUBLE_T);
+      add(name, expr_type(double_type()));
     }
 
     void function_signatures::add_unary(const::std::string& name) {
-      add(name, DOUBLE_T, DOUBLE_T);
+      add(name, expr_type(double_type()), expr_type(double_type()));
     }
 
     void function_signatures::add_unary_vectorized(const::std::string&
     name) {
       for (size_t i = 0; i < 8; ++i) {
-        add(name, expr_type(DOUBLE_T, i), expr_type(INT_T, i));
-        add(name, expr_type(DOUBLE_T, i), expr_type(DOUBLE_T, i));
-        add(name, expr_type(VECTOR_T, i), expr_type(VECTOR_T, i));
-        add(name, expr_type(ROW_VECTOR_T, i), expr_type(ROW_VECTOR_T, i));
-        add(name, expr_type(MATRIX_T, i), expr_type(MATRIX_T, i));
+        add(name, expr_type(double_type(), i), expr_type(int_type(), i));
+        add(name, expr_type(double_type(), i), expr_type(double_type(), i));
+        add(name, expr_type(vector_type(), i), expr_type(vector_type(), i));
+        add(name, expr_type(row_vector_type(), i),
+            expr_type(row_vector_type(), i));
+        add(name, expr_type(matrix_type(), i), expr_type(matrix_type(), i));
       }
     }
 
     void function_signatures::add_binary(const::std::string& name) {
-      add(name, DOUBLE_T, DOUBLE_T, DOUBLE_T);
+      add(name, expr_type(double_type()), expr_type(double_type()),
+          expr_type(double_type()));
     }
 
     void function_signatures::add_ternary(const::std::string& name) {
-      add(name, DOUBLE_T, DOUBLE_T, DOUBLE_T, DOUBLE_T);
+      add(name, expr_type(double_type()), expr_type(double_type()),
+          expr_type(double_type()), expr_type(double_type()));
     }
 
     void function_signatures::add_quaternary(const::std::string& name) {
-      add(name, DOUBLE_T, DOUBLE_T, DOUBLE_T, DOUBLE_T, DOUBLE_T);
+      add(name, expr_type(double_type()), expr_type(double_type()),
+          expr_type(double_type()), expr_type(double_type()),
+          expr_type(double_type()));
+    }
+
+    template<typename T>
+    expr_type function_signatures::rng_return_type(const expr_type& t) {
+      T return_type;
+      return expr_type(return_type, !t.is_primitive());
+    }
+
+    template<typename T>
+    expr_type function_signatures::rng_return_type(
+                            const expr_type& t,
+                            const expr_type& u) {
+      T return_type;
+      return t.is_primitive() && u.is_primitive()
+        ? expr_type(return_type) : expr_type(return_type, 1U);
+    }
+
+    template<typename T>
+    expr_type function_signatures::rng_return_type(
+                            const expr_type& t,
+                            const expr_type& u,
+                            const expr_type& v) {
+      return rng_return_type<T>(rng_return_type<T>(t, u), v);
     }
 
     int function_signatures::num_promotions(
