@@ -6,6 +6,7 @@
 
 #include <stan/lang/ast.hpp>
 
+#include <stan/lang/ast/base_expr_type_def.hpp>
 #include <stan/lang/ast/expr_type_def.hpp>
 #include <stan/lang/ast/scope_def.hpp>
 #include <stan/lang/ast/variable_map_def.hpp>
@@ -56,14 +57,12 @@
 #include <stan/lang/ast/node/algebra_solver_control_def.hpp>
 #include <stan/lang/ast/node/arg_decl_def.hpp>
 #include <stan/lang/ast/node/array_expr_def.hpp>
-#include <stan/lang/ast/node/assignment_def.hpp>
 #include <stan/lang/ast/node/assgn_def.hpp>
 #include <stan/lang/ast/node/base_var_decl_def.hpp>
 #include <stan/lang/ast/node/binary_op_def.hpp>
 #include <stan/lang/ast/node/break_continue_statement_def.hpp>
 #include <stan/lang/ast/node/cholesky_factor_var_decl_def.hpp>
 #include <stan/lang/ast/node/cholesky_corr_var_decl_def.hpp>
-#include <stan/lang/ast/node/compound_assignment_def.hpp>
 #include <stan/lang/ast/node/conditional_op_def.hpp>
 #include <stan/lang/ast/node/conditional_statement_def.hpp>
 #include <stan/lang/ast/node/corr_matrix_var_decl_def.hpp>
@@ -73,6 +72,8 @@
 #include <stan/lang/ast/node/expression_def.hpp>
 #include <stan/lang/ast/node/expression_type_vis_def.hpp>
 #include <stan/lang/ast/node/for_statement_def.hpp>
+#include <stan/lang/ast/node/for_array_statement_def.hpp>
+#include <stan/lang/ast/node/for_matrix_statement_def.hpp>
 #include <stan/lang/ast/node/function_decl_def_def.hpp>
 #include <stan/lang/ast/node/function_decl_defs_def.hpp>
 #include <stan/lang/ast/node/fun_def.hpp>
@@ -86,6 +87,7 @@
 #include <stan/lang/ast/node/integrate_ode_control_def.hpp>
 #include <stan/lang/ast/node/lb_idx_def.hpp>
 #include <stan/lang/ast/node/lub_idx_def.hpp>
+#include <stan/lang/ast/node/map_rect_def.hpp>
 #include <stan/lang/ast/node/matrix_var_decl_def.hpp>
 #include <stan/lang/ast/node/multi_idx_def.hpp>
 #include <stan/lang/ast/node/omni_idx_def.hpp>
