@@ -20,6 +20,8 @@ namespace stan {
      * specified stream.
      *
      * @param[in] fun function declaration
+     * @param[in] namespaces vector of strings used to generate the 
+     *   namespaces generated code is nested in.
      * @param[in] is_rng true if function is an RNG
      * @param[in] is_lp true if function accesses log density
      * accumulator
@@ -29,6 +31,7 @@ namespace stan {
      * @param[in,out] o stream for generating
      */
     void generate_function_instantiation_body(const function_decl_def& fun,
+                                    const std::vector<std::string>& namespaces,
                                     bool is_rng, bool is_lp, bool is_log,
                                     const std::string& rng_class,
                                     std::ostream& o) {
@@ -37,6 +40,10 @@ namespace stan {
       if (!fun.return_type_.is_void()) {
         o << "return ";
       }
+      o << EOL;
+      for (const std::string& namespace_i : namespaces) {
+        o << namespace_i << "::";
+      }
       generate_function_name(fun, o);
       generate_function_instantiation_template_parameters(
         fun, is_rng, is_lp, is_log, rng_class, o);
@@ -57,7 +64,6 @@ namespace stan {
       if (is_rng || is_lp || fun.arg_decls_.size() > 0)
         o << ", ";
       o << "pstream__";
-
       o << ");" << EOL;
       o << "}" << EOL;
     }
