@@ -385,12 +385,20 @@ namespace stan {
     add_conditional_body_f;
 
     // called from: statement_grammar
-    struct deprecate_old_assignment_op : public phoenix_functor_unary {
-      void operator()(std::ostream& error_msgs) const;
+    struct deprecate_old_assignment_op : public phoenix_functor_binary {
+      void operator()(std::string& op, std::ostream& error_msgs) const;
     };
     extern boost::phoenix::function<deprecate_old_assignment_op>
     deprecate_old_assignment_op_f;
 
+    // called from: statement_grammar
+    struct non_void_return_msg : public phoenix_functor_ternary {
+      void operator()(scope var_scope, bool& pass, std::ostream& error_msgs)
+        const;
+    };
+    extern boost::phoenix::function<non_void_return_msg>
+    non_void_return_msg_f;
+
     // called from: statement_grammar
     struct validate_return_allowed : public phoenix_functor_ternary {
       void operator()(scope var_scope, bool& pass, std::ostream& error_msgs)
@@ -408,9 +416,17 @@ namespace stan {
     validate_void_return_allowed_f;
 
     // called from: statement_grammar
-    struct validate_lhs_var_assgn : public phoenix_functor_senary {
-      void operator()(const std::string& name, const scope& var_scope,
-                      variable& v, bool& pass, const variable_map& vm,
+    struct set_lhs_var_assgn : public phoenix_functor_quinary {
+      void operator()(assgn& a, const std::string& name, bool& pass,
+                      const variable_map& vm, std::ostream& error_msgs) const;
+    };
+    extern boost::phoenix::function<set_lhs_var_assgn>
+    set_lhs_var_assgn_f;
+
+    // called from: statement_grammar
+    struct validate_lhs_var_assgn : public phoenix_functor_quinary {
+      void operator()(assgn& a, const scope& var_scope,
+                      bool& pass, const variable_map& vm,
                       std::ostream& error_msgs) const;
     };
     extern boost::phoenix::function<validate_lhs_var_assgn>
@@ -418,30 +434,12 @@ namespace stan {
 
     // called from: statement_grammar
     struct validate_assgn : public phoenix_functor_quaternary {
-      void operator()(const assgn& a, bool& pass,
+      void operator()(assgn& a, bool& pass,
                       const variable_map& vm, std::ostream& error_msgs)
         const;
     };
     extern boost::phoenix::function<validate_assgn> validate_assgn_f;
 
-    // called from: statement_grammar
-    struct validate_assignment : public phoenix_functor_quinary {
-      void operator()(assignment& a, const scope& var_scope,
-                      bool& pass, const variable_map& vm,
-                      std::ostream& error_msgs) const;
-    };
-    extern boost::phoenix::function<validate_assignment>
-    validate_assignment_f;
-
-    // called from: statement_grammar
-    struct validate_compound_assignment : public phoenix_functor_quinary {
-      void operator()(compound_assignment& a, const scope& var_scope,
-                      bool& pass, variable_map& vm, std::ostream& error_msgs)
-        const;
-    };
-    extern boost::phoenix::function<validate_compound_assignment>
-    validate_compound_assignment_f;
-
     // called from: statement_grammar
     struct validate_sample : public phoenix_functor_quaternary {
       void operator()(sample& s, const variable_map& var_map,
@@ -478,14 +476,43 @@ namespace stan {
     extern boost::phoenix::function<add_while_body> add_while_body_f;
 
     // called from: statement_grammar
-    struct add_loop_identifier : public phoenix_functor_senary {
+    struct add_loop_identifier : public phoenix_functor_ternary {
       void operator()(const std::string& name,
-                      std::string& name_local,
+                      const scope& var_scope,
+                      variable_map& vm) const;
+    };
+    extern boost::phoenix::function<add_loop_identifier> add_loop_identifier_f;
+
+    // called from: statement_grammar
+    struct add_array_loop_identifier : public phoenix_functor_quinary {
+      void operator()(const stan::lang::expression& expr,
+                      std::string& name,
+                      const scope& var_scope,
+                      bool& pass, variable_map& vm) const;
+    };
+    extern boost::phoenix::function<add_array_loop_identifier>
+      add_array_loop_identifier_f;
+
+    // called from: statement_grammar
+    struct add_matrix_loop_identifier : public phoenix_functor_senary {
+      void operator()(const stan::lang::expression& expr,
+                      std::string& name,
                       const scope& var_scope,
                       bool& pass, variable_map& vm,
                       std::stringstream& error_msgs) const;
     };
-    extern boost::phoenix::function<add_loop_identifier> add_loop_identifier_f;
+    extern boost::phoenix::function<add_matrix_loop_identifier>
+      add_matrix_loop_identifier_f;
+
+    // called from: statement_grammar
+    struct store_loop_identifier : public phoenix_functor_quinary {
+      void operator()(const std::string& name,
+                      std::string& name_local,
+                      bool& pass, variable_map& vm,
+                      std::stringstream& error_msgs) const;
+    };
+    extern boost::phoenix::function<store_loop_identifier>
+      store_loop_identifier_f;
 
     // called from: statement_grammar
     struct remove_loop_identifier : public phoenix_functor_binary {
@@ -591,6 +618,33 @@ namespace stan {
     extern boost::phoenix::function<validate_algebra_solver_control>
     validate_algebra_solver_control_f;
 
+    // called from: term_grammar
+    /**
+     * Functor for validating the arguments to map_rect.
+     */
+    struct validate_map_rect : public phoenix_functor_quaternary {
+      /**
+       * Validate that the specified rectangular map object has
+       * appropriately typed arguments and assign it a unique
+       * identifier, setting the pass flag to false and writing an
+       * error message to the output stream if they don't.
+       *
+       * @param[in,out] mr structure to validate
+       * @param[in] var_map mapping for variables
+       * @param[in,out] pass reference to set to false upon failure
+       * @param[in,out] error_msgs reference to error message stream
+       * @throws std::illegal_argument_exception if the arguments are
+       * not of the appropriate shapes.
+       */
+      void operator()(map_rect& mr,
+                      const variable_map& var_map, bool& pass,
+                      std::ostream& error_msgs) const;
+    };
+    /**
+     * Phoenix wrapper for the rectangular map structure validator.
+     */
+    extern boost::phoenix::function<validate_map_rect> validate_map_rect_f;
+
     // called from: term_grammar
     struct set_fun_type_named : public phoenix_functor_senary {
       void operator()(expression& fun_result, fun& fun,
@@ -759,6 +813,7 @@ namespace stan {
       bool operator()(const integrate_ode_control& x) const;
       bool operator()(const algebra_solver& x) const;
       bool operator()(const algebra_solver_control& x) const;
+      bool operator()(const map_rect& x) const;
       bool operator()(const fun& x) const;
       bool operator()(const index_op& x) const;
       bool operator()(const index_op_sliced& x) const;
@@ -826,6 +881,13 @@ namespace stan {
     };
     extern boost::phoenix::function<validate_int_expr> validate_int_expr_f;
 
+    struct validate_int_expr_no_error_msgs : public phoenix_functor_ternary {
+      void operator()(const expression& expr, bool& pass,
+                      std::stringstream& error_msgs) const;
+    };
+    extern boost::phoenix::function<validate_int_expr_no_error_msgs>
+      validate_int_expr_no_error_msgs_f;
+
     struct set_int_range_lower : public phoenix_functor_quaternary {
       void operator()(range& range, const expression& expr, bool& pass,
                       std::stringstream& error_msgs) const;
