@@ -18,20 +18,8 @@
 BOOST_FUSION_ADAPT_STRUCT(stan::lang::assgn,
                           (stan::lang::variable, lhs_var_)
                           (std::vector<stan::lang::idx>, idxs_)
-                          (stan::lang::expression, rhs_) )
-
-BOOST_FUSION_ADAPT_STRUCT(stan::lang::assignment,
-                          (stan::lang::variable_dims, var_dims_)
-                          (stan::lang::expression, expr_) )
-
-BOOST_FUSION_ADAPT_STRUCT(stan::lang::compound_assignment,
-                          (stan::lang::variable_dims, var_dims_)
                           (std::string, op_)
-                          (stan::lang::expression, expr_) )
-
-BOOST_FUSION_ADAPT_STRUCT(stan::lang::variable_dims,
-                          (std::string, name_)
-                          (std::vector<stan::lang::expression>, dims_) )
+                          (stan::lang::expression, rhs_) )
 
 BOOST_FUSION_ADAPT_STRUCT(stan::lang::distribution,
                           (std::string, family_)
@@ -42,6 +30,16 @@ BOOST_FUSION_ADAPT_STRUCT(stan::lang::for_statement,
                           (stan::lang::range, range_)
                           (stan::lang::statement, statement_) )
 
+BOOST_FUSION_ADAPT_STRUCT(stan::lang::for_array_statement,
+                          (std::string, variable_)
+                          (stan::lang::expression, expression_)
+                          (stan::lang::statement, statement_) )
+
+BOOST_FUSION_ADAPT_STRUCT(stan::lang::for_matrix_statement,
+                          (std::string, variable_)
+                          (stan::lang::expression, expression_)
+                          (stan::lang::statement, statement_) )
+
 BOOST_FUSION_ADAPT_STRUCT(stan::lang::return_statement,
                           (stan::lang::expression, return_value_) )
 
@@ -114,16 +112,16 @@ namespace stan {
         | increment_log_prob_statement_r(_r1)       // key "increment_log_prob"
         | increment_target_statement_r(_r1)         // key "target"
         | for_statement_r(_r1)                      // key "for"
+        | for_array_statement_r(_r1)                // key "for"
+        | for_matrix_statement_r(_r1)               // key "for"
         | while_statement_r(_r1)                    // key "while"
         | break_continue_statement_r(_r2)           // key "break", "continue"
         | statement_2_g(_r1, _r2)                   // key "if"
         | print_statement_r(_r1)                    // key "print"
         | reject_statement_r(_r1)                   // key "reject"
-        | return_statement_r(_r1)                   // key "return"
         | void_return_statement_r(_r1)              // key "return"
-        | assignment_r(_r1)                         // lvalue "=" or "<-"
-        | compound_assignment_r(_r1)                // lvalue "+=" or "-="
-        | assgn_r(_r1)                              // var[idxs] <- expr
+        | return_statement_r(_r1)                   // key "return"
+        | assgn_r(_r1)                              // var[idxs] = expr
         | sample_r(_r1)                             // expression "~"
         | expression_g(_r1)                         // expression
         [expression_as_statement_f(_pass, _1,
@@ -190,13 +188,52 @@ namespace stan {
       // _r1 = var scope
       for_statement_r.name("for statement");
       for_statement_r
+        %= lit("for")
+        >> no_skip[!char_("a-zA-Z0-9_")]
+        >> lit('(')
+        >> identifier_r[store_loop_identifier_f(_1, _a, _pass,
+                                         boost::phoenix::ref(var_map_),
+                                         boost::phoenix::ref(error_msgs_))]
+        >> lit("in")
+        >> (range_r(_r1)
+            > lit(')'))
+        >> (eps[add_loop_identifier_f(_a, _r1,
+                                      boost::phoenix::ref(var_map_))]
+            > statement_r(_r1, true))
+        > eps
+        [remove_loop_identifier_f(_a, boost::phoenix::ref(var_map_))];
+
+      // _r1 = var scope
+      for_array_statement_r.name("for statement, loop over array");
+      for_array_statement_r
+        %= lit("for")
+        >> no_skip[!char_("a-zA-Z0-9_")]
+        >> lit('(')
+        >> identifier_r[store_loop_identifier_f(_1, _a, _pass,
+                                         boost::phoenix::ref(var_map_),
+                                         boost::phoenix::ref(error_msgs_))]
+        >> lit("in")
+        >> (expression_rhs_r(_r1)[add_array_loop_identifier_f(_1, _a, _r1,
+                                         _pass,
+                                         boost::phoenix::ref(var_map_))]
+            > lit(')'))
+        >> (eps
+            > statement_r(_r1, true))
+        > eps
+           [remove_loop_identifier_f(_a, boost::phoenix::ref(var_map_))];
+
+      // _r1 = var scope
+      for_matrix_statement_r.name("for statement, loop over vector or matrix");
+      for_matrix_statement_r
         %= (lit("for") >> no_skip[!char_("a-zA-Z0-9_")])
         > lit('(')
-        > identifier_r[add_loop_identifier_f(_1, _a, _r1, _pass,
+        > identifier_r[store_loop_identifier_f(_1, _a, _pass,
                                          boost::phoenix::ref(var_map_),
                                          boost::phoenix::ref(error_msgs_))]
         > lit("in")
-        > range_r(_r1)
+        > expression_rhs_r(_r1)[add_matrix_loop_identifier_f(_1, _a, _r1, _pass,
+                                         boost::phoenix::ref(var_map_),
+                                         boost::phoenix::ref(error_msgs_))]
         > lit(')')
         > statement_r(_r1, true)
         > eps
@@ -240,93 +277,58 @@ namespace stan {
       range_r.name("range expression pair, colon");
       range_r
         %= expression_g(_r1)
-           [validate_int_expr_f(_1, _pass,
+           [validate_int_expr_no_error_msgs_f(_1, _pass,
                                      boost::phoenix::ref(error_msgs_))]
         >> lit(':')
         >> expression_g(_r1)
-           [validate_int_expr_f(_1, _pass,
+           [validate_int_expr_no_error_msgs_f(_1, _pass,
                                      boost::phoenix::ref(error_msgs_))];
 
       // _r1 = var scope
-      // this one comes before assgn_r to deal with simple assignment
-      assignment_r.name("variable assignment by expression");
-      assignment_r
-        %= var_lhs_r(_r1)
-        >> assignment_operator_r
-        > expression_rhs_r(_r1)
-          [validate_assignment_f(_val, _r1, _pass,
-                                 boost::phoenix::ref(var_map_),
-                                 boost::phoenix::ref(error_msgs_))]
-        > lit(';');
-
-      // _r1 = var scope
-      compound_assignment_r.name("variable compound op-equals by expression");
-      compound_assignment_r
-        %= var_lhs_r(_r1)
-        >> (string("+=")
-            | string("-=")
-            | string("*=")
-            | string("/=")
-            | string(".*=")
-            | string("./="))
-        >> expression_rhs_r(_r1)
-           [validate_compound_assignment_f(_val, _r1, _pass,
-                                           boost::phoenix::ref(var_map_),
-                                           boost::phoenix::ref(error_msgs_))]
-        > lit(';');
-
-      // _r1 = var scope
-      assgn_r.name("indexed variable assginment statement");
+      assgn_r.name("assignment statement");
       assgn_r
-        %= var_r(_r1)
-        >> indexes_g(_r1)
+        %= identifier_r[set_lhs_var_assgn_f(_val, _1, _pass,
+                                            boost::phoenix::ref(var_map_),
+                                            boost::phoenix::ref(error_msgs_))]
+        >> opt_idxs_r(_r1)
         >> assignment_operator_r
-        >> (eps > expression_rhs_r(_r1))
-           [validate_assgn_f(_val, _pass,
-                             boost::phoenix::ref(var_map_),
-                             boost::phoenix::ref(error_msgs_))]
+        >> (eps[validate_lhs_var_assgn_f(_val, _r1, _pass,
+                                         boost::phoenix::ref(var_map_),
+                                         boost::phoenix::ref(error_msgs_))]
+            > expression_rhs_r(_r1))
+              [validate_assgn_f(_val, _pass,
+                                boost::phoenix::ref(var_map_),
+                                boost::phoenix::ref(error_msgs_))]
         > lit(';');
 
       assignment_operator_r.name("assignment operator");
       assignment_operator_r
-        %= lit("<-")
-           [deprecate_old_assignment_op_f(boost::phoenix::ref(error_msgs_))]
-        | (lit("=") >> no_skip[!char_("=")]);
+        %= (string("=") >> no_skip[!char_("=")])
+        | string("+=")
+        | string("-=")
+        | string("*=")
+        | string("/=")
+        | string(".*=")
+        | string("./=")
+        | string("<-")
+          [deprecate_old_assignment_op_f(_val,
+                                         boost::phoenix::ref(error_msgs_))];
 
-      // _r1 = var scope
-      var_r.name("variable for left-hand side of assignment");
-      var_r
-        = identifier_r
-          [validate_lhs_var_assgn_f(_1, _r1, _val,  _pass,
-                                    boost::phoenix::ref(var_map_),
-                                    boost::phoenix::ref(error_msgs_))];
-
-      // separate rule for name on expectation failure
       // _r1 = var scope
       expression_rhs_r.name("expression assignable to left-hand side");
       expression_rhs_r
         %= expression_g(_r1);
 
       // _r1 = var scope
-      var_lhs_r.name("variable and array dimensions");
-      var_lhs_r
-        %= identifier_r
-        >> opt_dims_r(_r1);
+      opt_idxs_r.name("array indexes (optional)");
+      opt_idxs_r
+        %=  *idxs_r(_r1);
+
+      idxs_r.name("array indexes");
+      idxs_r
+        %= indexes_g(_r1);
 
       // _r1 = var scope
-      opt_dims_r.name("array dimensions (optional)");
-      opt_dims_r
-        %=  *dims_r(_r1);
-
-      // _r1 = var scope
-      dims_r.name("array dimensions");
-      // uses silent test because errors will be reported in sliced rules
-      dims_r
-        %= lit('[')
-        >> (expression_g(_r1)[validate_int_expr_silent_f(_1, _pass)] % ',')
-        >> lit(']');
-
-      // inherited  _r1 = var scope
       sample_r.name("distribution of expression");
       sample_r
         %= (expression_g(_r1)
@@ -359,14 +361,6 @@ namespace stan {
         > -expression_g(_r1)
         > lit(']');
 
-      // _r1 = var scope
-      return_statement_r.name("return statement");
-      return_statement_r
-        %= (lit("return") >> no_skip[!char_("a-zA-Z0-9_")])
-        >> expression_g(_r1)
-        >> lit(';') [validate_return_allowed_f(_r1, _pass,
-                                     boost::phoenix::ref(error_msgs_))];
-
       // _r1 = var scope
       void_return_statement_r.name("void return statement");
       void_return_statement_r
@@ -374,6 +368,18 @@ namespace stan {
         >> lit(';') [validate_void_return_allowed_f(_r1, _pass,
                                           boost::phoenix::ref(error_msgs_))];
 
+      // _r1 = var scope
+      return_statement_r.name("return statement");
+      return_statement_r
+        %= (lit("return") >> no_skip[!char_("a-zA-Z0-9_")])
+        > (expression_g(_r1)
+           | (eps[non_void_return_msg_f(_r1, _pass,
+                                        boost::phoenix::ref(error_msgs_))]
+              > expression_g(_r1)))
+        > lit(';') [validate_return_allowed_f(_r1, _pass,
+                                     boost::phoenix::ref(error_msgs_))];
+
+
       no_op_statement_r.name("no op statement");
       no_op_statement_r
         %= lit(';') [set_no_op_f(_val)];
